import { HStack } from '@chakra-ui/react'
import React, { memo, useEffect, useState } from 'react'
import { useDispatch } from 'react-redux'

import { Profile } from '../components'
import { users } from '../__data__/users'
import { setStars } from '../__data__/actions/stars'
import { ProfileEditModal } from '../components/profileEdit'

export const Friends = memo(() => {
  const [isLoading, setIsLoading] = useState(false)
  const [data, setData] = useState(null)
  const [error, setError] = useState(null)
  const dispatch = useDispatch()
  const [showModal, setShowModal] = useState(false)

  useEffect(() => {
    const getUser = async () => {
      setIsLoading(true)

      try {
        const response = await fetch('/api/users/')

        if (response.ok) {
          const data = (await response.json()).body
          setData(data)

          Object.keys(data).forEach(userId => {
            dispatch(setStars({ id: userId, value: data[userId].rated }))
          })
        } else {
          throw 'Что-то пошло не так'
        }

      } catch (e) {
        setError(e.message)
      } finally {
        setIsLoading(false)
      }
    }

    getUser()
  }, [])

  if(!data || isLoading) return <h1>loading...</h1>
  
  return (
    <>
      {showModal && <ProfileEditModal onClose={() => setShowModal(false)} />}
      <HStack>
        <Profile onOpenModal={() => setShowModal(true)} user={data['some-user-id']} />
        <Profile onOpenModal={() => setShowModal(true)} user={data['2']} />
      </HStack>
    </>
  )
})

Friends.displayName = 'memo(Friends)'
